#!/usr/bin/sh

#
# The source here is entirely from an openssl-0.9.* distribution except for:
#
# - openssl-0.9.sh (this file)
# - openssl-0.9.depend (depend file for build script)
# - openssl-0.9-patches
#

set -x
set -e

# Apply patches.
[ -f openssl-0.9-been-patched ] || {
	/usr/bin/patch -p1 -i openssl-0.9-patches
	date >openssl-0.9-been-patched
}

# Define prefix and openssl dir -- use relative pathnames.
PREFIX=usr
OPENSSLDIR=etc/ssl

# these directories of links exist in the source yet as complete
# files in our checkin.  They are evil, and need to be vanguished.
# These cause duplicates that the softlinking process (make links,
# called by Configure) fails but ignores, so the old version
# remains.  Remove completely after UP4.  causes fz528767 item #2
# OpenSSL has a history of shipping generated files in the source
# tree and similar sins.

for i in test/bftest.c test/bntest.c test/casttest.c test/destest.c \
test/dhtest.c test/dsatest.c test/ectest.c test/enginetest.c \
test/evp_test.c test/evptests.txt test/exptest.c test/hmactest.c test/ideatest.c \
test/Makefile test/md2test.c test/md4test.c test/md5test.c \
test/mdc2test.c test/randtest.c test/rc2test.c test/rc4test.c \
test/rc5test.c test/rmdtest.c test/rsa_test.c test/sha1test.c \
test/shatest.c test/ssltest.c \
apps/md4.c include/openssl \
; do
        rm -fr $i
done

# Another truly evil habit of OpenSSL is to read, then write, generated
# files.  Ignoring the possibility of one bad write forever corrupting
# the target, we need to at least make these writeable.  This was changed
# in clearcase, but building out of the tree keeps choking on this, so I
# add this change here.
for i in crypto/objects/obj_dat.h crypto/objects/obj_mac.h crypto/objects/obj_mac.num
do
	chmod +w $i
done

# Configure -- enable shared library creation, and libz.
./config \
	--prefix=/${PREFIX} --openssldir=/${OPENSSLDIR} \
	shared zlib-dynamic

#
# Make libraries and install header files and libraries in xenv.
# Override hardcoded CC and AR in Makefiles.
#
${MAKE} CC=${CC} AR="${AR} ${ARFLAGS}" \
	INSTALL_PREFIX=${TOOLS} install_hdrs install_libs

# Now make everything and install in ${ROOT}/${MACH}.
${MAKE} CC=${CC} AR="${AR} ${ARFLAGS}" \
	INSTALL_PREFIX=${ROOT}/${MACH} install

#
# Move man pages to Unix standard directories.
# We are not modifying Makefile.org since this is UnixWare specific change.
#

# Move all files from directory $1 to $2.
_mv()
{
	[ ! -d $2 ] && mkdir -p $2
	/usr/bin/ls $1 | /usr/bin/xargs -i /usr/bin/mv -f $1/{} $2/{}
}

cd ${ROOT}/${MACH}
_mv ${OPENSSLDIR}/man/man1 ${PREFIX}/man/man.1
_mv ${OPENSSLDIR}/man/man3 ${PREFIX}/man/man.3
_mv ${OPENSSLDIR}/man/man5 ${PREFIX}/man/man.5
_mv ${OPENSSLDIR}/man/man7 ${PREFIX}/man/man.7
